@@ -27,6 +27,7 @@ import gettext
 import locale
 import pango
 import os
+import re
 from xml.sax import saxutils
 from series import SeriesManager, Show, Episode
 from lib import constants
@@ -64,9 +65,13 @@ class MainWindow(hildon.StackableWindow):
                                                   self)
 
         self.series_manager = SeriesManager()
+        self.settings = Settings()
         hildon.hildon_gtk_window_set_progress_indicator(self, True)
+        load_conf_item = AsyncItem(self.settings.load,
+                                   (constants.SF_CONF_FILE,))
         load_shows_item = AsyncItem(self.series_manager.load,
-                                    (constants.SF_DB_FILE,))
+                                    (constants.SF_DB_FILE,),
+                                    self._load_finished)
         self.series_manager.connect('show-list-changed',
                                     self._show_list_changed_cb)
         self.series_manager.connect('get-full-show-complete',
@@ -78,26 +83,32 @@ class MainWindow(hildon.StackableWindow):
         self.series_manager.connect('updated-show-art',
                                     self._update_show_art)
 
-        self.settings = Settings()
-        load_conf_item = AsyncItem(self.settings.load,
-                                    (constants.SF_CONF_FILE,),
-                                    self._load_finished)
         self.request = AsyncWorker()
-        self.request.queue.put((0, load_shows_item))
         self.request.queue.put((0, load_conf_item))
+        self.request.queue.put((0, load_shows_item))
         self.request.start()
 
         self.shows_view = ShowsSelectView()
         self.shows_view.connect('row-activated', self._row_activated_cb)
         self.set_title(constants.SF_NAME)
         self.set_app_menu(self._create_menu())
+        self.live_search = LiveSearchEntry(self.shows_view.tree_model,
+                                           self.shows_view.tree_filter,
+                                           ShowListStore.SEARCH_COLUMN)
         area = hildon.PannableArea()
         area.add(self.shows_view)
-        self.add(area)
+        box = gtk.VBox()
+        box.pack_start(area)
+        box.pack_end(self.live_search, False, False)
+        self.add(box)
+        box.show_all()
+        self.live_search.hide()
 
         self.connect('delete-event', self._exit_cb)
         self._update_delete_menu_visibility()
 
+        self.connect('key-press-event', self._key_press_event_cb)
+
         self._have_deleted = False
 
     def _load_finished(self, dummy_arg, error):
@@ -115,7 +126,7 @@ class MainWindow(hildon.StackableWindow):
         menu = hildon.AppMenu()
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Add Shows'))
+        button.set_label(_('Add shows'))
         button.connect('clicked', self._add_shows_cb)
         menu.append(button)
 
@@ -123,25 +134,28 @@ class MainWindow(hildon.StackableWindow):
                                         gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.sort_by_ep_filter.set_mode(False)
         self.sort_by_ep_filter.set_label(_('Sort by ep. date'))
-        self.sort_by_ep_filter.connect('clicked',
-                                lambda w: self.shows_view.sort_by_recent_date())
         menu.add_filter(self.sort_by_ep_filter)
         self.sort_by_name_filter = hildon.GtkRadioButton(
                                           gtk.HILDON_SIZE_FINGER_HEIGHT,
                                           group = self.sort_by_ep_filter)
         self.sort_by_name_filter.set_mode(False)
         self.sort_by_name_filter.set_label(_('Sort by name'))
+        menu.add_filter(self.sort_by_name_filter)
+        self.sort_by_name_filter.set_active(
+            self.settings.getConf(Settings.SHOWS_SORT) != \
+                Settings.RECENT_EPISODE)
+        self.sort_by_ep_filter.connect('clicked',
+                                lambda w: self.shows_view.sort_by_recent_date())
         self.sort_by_name_filter.connect('clicked',
                              lambda w: self.shows_view.sort_by_name_ascending())
-        menu.add_filter(self.sort_by_name_filter)
 
         self.delete_menu = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        self.delete_menu.set_label(_('Delete Shows'))
+        self.delete_menu.set_label(_('Delete shows'))
         self.delete_menu.connect('clicked', self._delete_shows_cb)
         menu.append(self.delete_menu)
 
         self.update_all_menu = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        self.update_all_menu.set_label(_('Update All'))
+        self.update_all_menu.set_label(_('Update all'))
         self.update_all_menu.connect('clicked', self._update_all_shows_cb)
         menu.append(self.update_all_menu)
 
@@ -196,7 +210,7 @@ class MainWindow(hildon.StackableWindow):
                 error_message = '\n ' + _('Please verify your internet connection '
                                           'is available')
                 show_information(self,
-                                 _('An error occurred.%s') % error_message)
+                                 _('An error occurred. %s') % error_message)
         else:
             self.shows_view.set_shows(self.series_manager.series_list)
             self._update_delete_menu_visibility()
@@ -209,6 +223,7 @@ class MainWindow(hildon.StackableWindow):
                      lambda w, e:
                         self.shows_view.update(show))
         seasons_view.show_all()
+        self.live_search.hide()
 
     def _new_show_dialog(self):
         new_show_dialog = NewShowDialog(self)
@@ -313,6 +328,12 @@ class MainWindow(hildon.StackableWindow):
                  self._rotation_manager.NEVER]
         self._rotation_manager.set_mode(modes[configured_mode])
 
+    def _key_press_event_cb(self, window, event):
+        char = gtk.gdk.keyval_to_unicode(event.keyval)
+        if self.live_search.is_focus() or char == 0 or not chr(char).strip():
+            return
+        self.live_search.show()
+
 class DeleteView(hildon.StackableWindow):
 
     def __init__(self,
@@ -340,7 +361,7 @@ class ShowsDeleteView(DeleteView):
     def __init__(self, series_manager):
         self.shows_select_view = ShowsSelectView()
         super(ShowsDeleteView, self).__init__(self.shows_select_view,
-                                               _('Delete Shows'),
+                                               _('Delete shows'),
                                                _('Delete'))
         self.series_manager = series_manager
         self.toolbar.connect('button-clicked',
@@ -361,42 +382,38 @@ class ShowsSelectView(gtk.TreeView):
 
     def __init__(self):
         super(ShowsSelectView, self).__init__()
-        model = ShowListStore()
+        self.tree_model = ShowListStore()
         show_image_renderer = gtk.CellRendererPixbuf()
         column = gtk.TreeViewColumn('Image', show_image_renderer,
-                                    pixbuf = model.IMAGE_COLUMN)
+                                    pixbuf = ShowListStore.IMAGE_COLUMN)
         self.append_column(column)
         show_renderer = gtk.CellRendererText()
         show_renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
-        column = gtk.TreeViewColumn('Name', show_renderer, markup = model.INFO_COLUMN)
-        self.set_model(model)
+        column = gtk.TreeViewColumn('Name', show_renderer, markup = ShowListStore.INFO_COLUMN)
+        self.tree_filter = self.tree_model.filter_new()
+        self.set_model(self.tree_filter)
         self.append_column(column)
-        self.sort_by_name_ascending()
+        self.sort()
 
     def set_shows(self, shows):
-        model = self.get_model()
-        model.add_shows(shows)
+        self.tree_model.add_shows(shows)
 
     def get_show_from_path(self, path):
-        model = self.get_model()
-        return model[path][model.SHOW_COLUMN]
+        return self.tree_model[path][self.tree_model.SHOW_COLUMN]
 
     def sort_by_recent_date(self):
-        model = self.get_model()
-        model.set_sort_column_id(model.NEXT_EPISODE_COLUMN,
-                                 gtk.SORT_ASCENDING)
+        self.tree_model.set_sort_column_id(self.tree_model.NEXT_EPISODE_COLUMN,
+                                           gtk.SORT_ASCENDING)
         Settings().setConf(Settings.SHOWS_SORT, Settings.RECENT_EPISODE)
 
     def sort_by_name_ascending(self):
-        model = self.get_model()
-        model.set_sort_column_id(model.INFO_COLUMN,
-                                 gtk.SORT_ASCENDING)
+        self.tree_model.set_sort_column_id(self.tree_model.INFO_COLUMN,
+                                           gtk.SORT_ASCENDING)
         Settings().setConf(Settings.SHOWS_SORT, Settings.ASCENDING_ORDER)
 
     def update(self, show = None):
-        model = self.get_model()
-        if model:
-            model.update(show)
+        if self.tree_model:
+            self.tree_model.update(show)
             self.sort()
 
     def sort(self):
@@ -411,10 +428,11 @@ class ShowListStore(gtk.ListStore):
     IMAGE_COLUMN = 0
     INFO_COLUMN = 1
     SHOW_COLUMN = 2
-    NEXT_EPISODE_COLUMN = 3
+    SEARCH_COLUMN = 3
+    NEXT_EPISODE_COLUMN = 4
 
     def __init__(self):
-        super(ShowListStore, self).__init__(gtk.gdk.Pixbuf, str, gobject.TYPE_PYOBJECT, gobject.TYPE_PYOBJECT)
+        super(ShowListStore, self).__init__(gtk.gdk.Pixbuf, str, gobject.TYPE_PYOBJECT, str, gobject.TYPE_PYOBJECT)
         self.cached_pixbufs = {}
         self.set_sort_func(self.NEXT_EPISODE_COLUMN, self._sort_func)
 
@@ -424,6 +442,7 @@ class ShowListStore(gtk.ListStore):
             row = {self.IMAGE_COLUMN: None,
                    self.INFO_COLUMN: saxutils.escape(show.name),
                    self.SHOW_COLUMN: show,
+                   self.SEARCH_COLUMN: saxutils.escape(show.name).lower(),
                    self.NEXT_EPISODE_COLUMN: None
                   }
             self.append(row.values())
@@ -540,24 +559,24 @@ class SeasonsView(hildon.StackableWindow):
         menu.append(button)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Edit Info'))
+        button.set_label(_('Edit info'))
         button.connect('clicked', self._edit_show_info)
         menu.append(button)
 
         self.update_menu = None
         if str(self.show.thetvdb_id) != '-1':
             self.update_menu = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-            self.update_menu.set_label(_('Update Show'))
+            self.update_menu.set_label(_('Update show'))
             self.update_menu.connect('clicked', self._update_series_cb)
             menu.append(self.update_menu)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Delete Season'))
+        button.set_label(_('Delete season'))
         button.connect('clicked', self._delete_seasons_cb)
         menu.append(button)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('New Episode'))
+        button.set_label(_('New episode'))
         button.connect('clicked', self._new_episode_cb)
         menu.append(button)
 
@@ -581,7 +600,7 @@ class SeasonsView(hildon.StackableWindow):
 
     def _show_info_cb(self, button):
         dialog = gtk.Dialog(parent = self)
-        dialog.set_title(_('Show Details'))
+        dialog.set_title(_('Show details'))
         infotextview = InfoTextView()
         infotextview.set_title(self.show.name)
         infotextview.add_field (self.show.overview)
@@ -610,6 +629,7 @@ class SeasonsView(hildon.StackableWindow):
             self.show.network = info['network']
             self.show.rating = info['rating']
             self.show.actors = info['actors']
+            self.series_manager.updated()
         self.set_title(self.show.name)
 
     def _new_episode_cb(self, button):
@@ -668,7 +688,7 @@ class SeasonsDeleteView(DeleteView):
         self.seasons_select_view = SeasonSelectView(seasons_select_view.show)
         self.seasons_select_view.set_model(seasons_select_view.get_model())
         super(SeasonsDeleteView, self).__init__(self.seasons_select_view,
-                                               _('Delete Seasons'),
+                                               _('Delete seasons'),
                                                _('Delete'))
         self.series_manager = series_manager
         self.toolbar.connect('button-clicked',
@@ -779,7 +799,7 @@ class NewShowDialog(gtk.Dialog):
                                              buttons = (gtk.STOCK_ADD,
                                                         gtk.RESPONSE_ACCEPT))
 
-        self.set_title(_('Edit Show'))
+        self.set_title(_('Edit show'))
 
         self.show_name = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.show_overview = hildon.TextView()
@@ -851,7 +871,7 @@ class NewEpisodeDialog(gtk.Dialog):
                                                buttons = (gtk.STOCK_ADD,
                                                           gtk.RESPONSE_ACCEPT))
 
-        self.set_title(_('New Episode'))
+        self.set_title(_('New episode'))
 
         self.episode_name = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.episode_overview = hildon.TextView()
@@ -903,7 +923,7 @@ class NewEpisodeDialog(gtk.Dialog):
                   (_('Writer:'), self.episode_writer),
                   (_('Original air date:'), self.episode_air_date),
                   (_('Rating:'), self.episode_rating),
-                  (_('Guest Stars:'), self.episode_guest_stars),
+                  (_('Guest stars:'), self.episode_guest_stars),
                  ]
         size_group = gtk.SizeGroup(gtk.SIZE_GROUP_BOTH)
         for text, widget in fields:
@@ -964,7 +984,8 @@ class EpisodesView(hildon.StackableWindow):
     def __init__(self, settings, show, season_number = None):
         super(EpisodesView, self).__init__()
 
-        self.settings = settings
+        self.settings = Settings()
+        self.series_manager = SeriesManager()
 
         self.show = show
         self.season_number = season_number
@@ -989,34 +1010,34 @@ class EpisodesView(hildon.StackableWindow):
     def _create_menu(self):
         menu = hildon.AppMenu()
 
-        button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_mode(False)
-        button.set_label(_('A-Z'))
-        button.connect('clicked', self._sort_ascending_cb)
-        menu.add_filter(button)
-        button = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, group = button)
-        button.set_mode(False)
-        button.set_label(_('Z-A'))
-        button.connect('clicked', self._sort_descending_cb)
-        menu.add_filter(button)
-        if self.settings.getConf(self.settings.EPISODES_ORDER_CONF_NAME) == \
-           self.settings.DESCENDING_ORDER:
-            button.set_active(True)
+        button_asc = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        button_asc.set_mode(False)
+        button_asc.set_label(_('A-Z'))
+        menu.add_filter(button_asc)
+        button_desc = hildon.GtkRadioButton(gtk.HILDON_SIZE_FINGER_HEIGHT, group = button_asc)
+        button_desc.set_mode(False)
+        button_desc.set_label(_('Z-A'))
+        menu.add_filter(button_desc)
+        if self.settings.getConf(Settings.EPISODES_ORDER_CONF_NAME) == \
+                Settings.ASCENDING_ORDER:
+            button_asc.set_active(True)
         else:
-            button.set_active(False)
+            button_desc.set_active(True)
+        button_asc.connect('clicked', self._sort_ascending_cb)
+        button_desc.connect('clicked', self._sort_descending_cb)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Mark All'))
+        button.set_label(_('Mark all'))
         button.connect('clicked', self._select_all_cb)
         menu.append(button)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Mark None'))
+        button.set_label(_('Mark none'))
         button.connect('clicked', self._select_none_cb)
         menu.append(button)
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Delete Episodes'))
+        button.set_label(_('Delete episodes'))
         button.connect('clicked', self._delete_episodes_cb)
         menu.append(button)
 
@@ -1039,7 +1060,7 @@ class EpisodesView(hildon.StackableWindow):
 
     def _row_activated_cb(self, view, path, column):
         episode = self.episodes_check_view.get_episode_from_path(path)
-        if self.episodes_check_view.get_column(1) == column:
+        if self.episodes_check_view.get_column(EpisodeListStore.INFO_COLUMN) == column:
             episodes_view = EpisodeView(episode)
             episodes_view.connect('delete-event', self._update_episodes_list_cb)
             episodes_view.show_all()
@@ -1056,7 +1077,8 @@ class EpisodesView(hildon.StackableWindow):
     def _watched_renderer_toggled_cb(self, renderer, path, model):
         episode = self.episodes_check_view.get_episode_from_path(path)
         episode.watched = not episode.watched
-        model[path][0] = episode.watched
+        episode.updated()
+        model[path][model.CHECK_COLUMN] = episode.watched
         model.update_iter(model.get_iter(path))
 
     def _sort_ascending_cb(self, button):
@@ -1070,19 +1092,25 @@ class EpisodesView(hildon.StackableWindow):
                               self.settings.DESCENDING_ORDER)
 
 class EpisodeListStore(gtk.ListStore):
-
     CHECK_COLUMN = 0
     INFO_COLUMN = 1
     EPISODE_COLUMN = 2
 
     def __init__(self):
-        super(EpisodeListStore, self).__init__(bool, str, gobject.TYPE_PYOBJECT)
+        EpisodeListStore.CHECK_COLUMN = Settings().getConf(Settings.EPISODES_CHECK_POSITION)
+        EpisodeListStore.INFO_COLUMN = 1 - EpisodeListStore.CHECK_COLUMN
+        types = {self.CHECK_COLUMN: bool, self.INFO_COLUMN: str,
+                 self.EPISODE_COLUMN: gobject.TYPE_PYOBJECT}
+        super(EpisodeListStore, self).__init__(*types.values())
 
     def add(self, episode_list):
         self.clear()
         for episode in episode_list:
             name = str(episode)
-            self.append([episode.watched, name, episode])
+            row = {self.CHECK_COLUMN: episode.watched,
+                   self.INFO_COLUMN: name,
+                   self.EPISODE_COLUMN: episode}
+            self.append(row.values())
         self.update()
 
 
@@ -1102,16 +1130,18 @@ class EpisodesCheckView(gtk.TreeView):
     def __init__(self):
         super(EpisodesCheckView, self).__init__()
         model = EpisodeListStore()
+        episode_renderer = gtk.CellRendererText()
+        episode_renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
+        if model.CHECK_COLUMN != 0:
+            episode_renderer.set_property('width', gtk.gdk.screen_get_default().get_width() - 150)
+        column = gtk.TreeViewColumn('Name', episode_renderer, markup = model.INFO_COLUMN)
+        self.append_column(column)
         self.watched_renderer = gtk.CellRendererToggle()
         self.watched_renderer.set_property('width', 100)
         self.watched_renderer.set_property('activatable', True)
         column = gtk.TreeViewColumn('Watched', self.watched_renderer)
         column.add_attribute(self.watched_renderer, "active", model.CHECK_COLUMN)
-        self.append_column(column)
-        episode_renderer = gtk.CellRendererText()
-        episode_renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
-        column = gtk.TreeViewColumn('Name', episode_renderer, markup = model.INFO_COLUMN)
-        self.append_column(column)
+        self.insert_column(column, model.CHECK_COLUMN)
         self.set_model(model)
         self.get_model().set_sort_func(2, self._sort_func)
 
@@ -1157,6 +1187,7 @@ class EpisodesCheckView(gtk.TreeView):
         for path in model or []:
             path[model.CHECK_COLUMN] = \
                 path[model.EPISODE_COLUMN].watched = mark
+            path[model.EPISODE_COLUMN].updated()
 
 class EpisodeView(hildon.StackableWindow):
 
@@ -1164,9 +1195,9 @@ class EpisodeView(hildon.StackableWindow):
         super(EpisodeView, self).__init__()
         self.episode = episode
 
-        self.set_title(str(self.episode))
-
         contents_area = hildon.PannableArea()
+        contents_area.connect('horizontal-movement',
+                              self._horizontal_movement_cb)
         contents = gtk.VBox(False, 0)
         contents_area.add_with_viewport(contents)
 
@@ -1180,14 +1211,15 @@ class EpisodeView(hildon.StackableWindow):
 
     def _update_info_text_view(self):
         self.infotextview.clear()
-        self.infotextview.set_title(self.episode.name)
+        self.infotextview.set_title('%(number)s - %(name)s' % {'name': self.episode.name,
+                                                               'number': self.episode.get_episode_show_number()})
         self.infotextview.add_field(self.episode.overview)
         self.infotextview.add_field('\n')
         self.infotextview.add_field(self.episode.get_air_date_text(),
                                     _('Original air date'))
         self.infotextview.add_field(self.episode.director, _('Director'))
         self.infotextview.add_field(self.episode.writer, _('Writer'))
-        self.infotextview.add_field(self.episode.guest_stars, _('Guest Stars'))
+        self.infotextview.add_field(self.episode.guest_stars, _('Guest stars'))
         self.infotextview.add_field(self.episode.rating, _('Rating'))
         self.set_title(self.episode.name)
 
@@ -1195,7 +1227,7 @@ class EpisodeView(hildon.StackableWindow):
         menu = hildon.AppMenu()
 
         button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        button.set_label(_('Edit Info'))
+        button.set_label(_('Edit info'))
         button.connect('clicked', self._edit_episode_cb)
         menu.append(button)
 
@@ -1217,15 +1249,26 @@ class EpisodeView(hildon.StackableWindow):
             self.episode.writer = episode_info['writer']
             self.episode.rating = episode_info['rating']
             self.episode.guest_stars = episode_info['guest_stars']
+            self.episode.updated()
             self._update_info_text_view()
         edit_episode_dialog.destroy()
 
+    def _horizontal_movement_cb(self, pannable_area, direction,
+                                initial_x, initial_y):
+        if direction == hildon.MOVEMENT_LEFT:
+            episode = self.episode.show.get_next_episode(self.episode)
+        else:
+            episode = self.episode.show.get_previous_episode(self.episode)
+        if episode:
+            self.episode = episode
+            self._update_info_text_view()
+
 class EpisodesDeleteView(DeleteView):
 
     def __init__(self, show):
         self.episodes_select_view = EpisodesSelectView()
         super(EpisodesDeleteView, self).__init__(self.episodes_select_view,
-                                                 _('Delete Episodes'),
+                                                 _('Delete episodes'),
                                                  _('Delete'))
         self.show = show
         self.toolbar.connect('button-clicked',
@@ -1304,6 +1347,61 @@ class InfoTextView(hildon.TextView):
         buffer.delete(buffer.get_start_iter(), buffer.get_end_iter())
         self.iter = buffer.get_start_iter()
 
+class LiveSearchEntry(gtk.HBox):
+
+    def __init__(self, tree_model, tree_filter, filter_column = 0):
+        super(LiveSearchEntry, self).__init__()
+        self.tree_model = tree_model
+        self.tree_filter = tree_filter
+        if not self.tree_model or not self.tree_filter:
+            return
+        self.filter_column = filter_column
+        self.tree_filter.set_visible_func(self._tree_filter_func)
+        self.entry = hildon.Entry(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.entry.set_input_mode(gtk.HILDON_GTK_INPUT_MODE_FULL)
+        self.entry.show()
+        self.entry.connect('changed',
+                           self._entry_changed_cb)
+        self.cancel_button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        image = gtk.image_new_from_icon_name('general_close',
+                                             gtk.ICON_SIZE_LARGE_TOOLBAR)
+        if image:
+            self.cancel_button.set_image(image)
+        else:
+            self.cancel_button.set_label(_('Cancel'))
+        self.cancel_button.set_size_request(self.cancel_button.get_size_request()[1], -1)
+        self.cancel_button.show()
+        self.cancel_button.connect('clicked', self._cancel_button_clicked_cb)
+        self.pack_start(self.entry)
+        self.pack_start(self.cancel_button, False, False)
+
+    def _cancel_button_clicked_cb(self, button):
+        self.hide()
+        self.entry.set_text('')
+
+    def _tree_filter_func(self, model, iter):
+        info = model.get_value(iter, self.filter_column) or ''
+        text_to_filter = self.entry.get_text().strip()
+        if not text_to_filter:
+            return True
+        expr = re.compile('(.*\s+)*(%s)' % re.escape(text_to_filter.lower()))
+        if expr.match(info):
+            return True
+        return False
+
+    def _entry_changed_cb(self, entry):
+        self.tree_filter.refilter()
+        if not entry.get_text():
+            self.hide()
+
+    def show(self):
+        gtk.HBox.show(self)
+        self.entry.grab_focus()
+
+    def hide(self):
+        gtk.HBox.hide(self)
+        self.entry.set_text('')
+
 class NewShowsDialog(gtk.Dialog):
 
     ADD_AUTOMATICALLY_RESPONSE = 1 << 0
@@ -1311,13 +1409,13 @@ class NewShowsDialog(gtk.Dialog):
 
     def __init__(self, parent):
         super(NewShowsDialog, self).__init__(parent = parent)
-        self.set_title(_('Add Shows'))
+        self.set_title(_('Add shows'))
         contents = gtk.HBox(True, 0)
         self.search_shows_button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        self.search_shows_button.set_label(_('Search Shows'))
+        self.search_shows_button.set_label(_('Search shows'))
         self.search_shows_button.connect('clicked', self._button_clicked_cb)
         self.manual_add_button = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
-        self.manual_add_button.set_label(_('Add Manually'))
+        self.manual_add_button.set_label(_('Add manually'))
         self.manual_add_button.connect('clicked', self._button_clicked_cb)
         contents.add(self.search_shows_button)
         contents.add(self.manual_add_button)
@@ -1445,7 +1543,7 @@ class SearchShowsDialog(gtk.Dialog):
             if 'socket' in str(error).lower():
                 error_message = '\n ' + _('Please verify your internet connection '
                                           'is available')
-                show_information(self, _('An error occurred.%s') % error_message)
+                show_information(self, _('An error occurred. %s') % error_message)
         else:
             model = self.shows_view.get_model()
             if not model:
@@ -1559,6 +1657,7 @@ class SettingsDialog(gtk.Dialog):
         self.settings = Settings()
         self.vbox.pack_start(self._create_screen_rotation_settings())
         self.vbox.pack_start(self._create_shows_settings())
+        self.vbox.pack_start(self._create_episodes_check_settings())
         self.vbox.show_all()
 
     def _create_screen_rotation_settings(self):
@@ -1567,7 +1666,7 @@ class SettingsDialog(gtk.Dialog):
         picker_button.set_alignment(0, 0.5, 0, 1)
         picker_button.set_done_button_text(_('Done'))
         selector = hildon.TouchSelector(text = True)
-        picker_button.set_title(_('Screen Rotation:'))
+        picker_button.set_title(_('Screen rotation:'))
         modes = [_('Automatic'), _('Portrait'), _('Landscape')]
         for mode in modes:
             selector.append_text(mode)
@@ -1585,12 +1684,30 @@ class SettingsDialog(gtk.Dialog):
                              self._special_seasons_check_button_toggled_cb)
         return check_button
 
+    def _create_episodes_check_settings(self):
+        picker_button = hildon.PickerButton(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                            hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+        picker_button.set_title(_('Episodes check position:'))
+        picker_button.set_alignment(0, 0.5, 0, 1)
+        selector = hildon.TouchSelector(text = True)
+        selector.append_text(_('Left'))
+        selector.append_text(_('Right'))
+        picker_button.set_selector(selector)
+        picker_button.set_active(self.settings.getConf(Settings.EPISODES_CHECK_POSITION))
+        picker_button.connect('value-changed',
+                              self._episodes_check_picker_button_changed_cb)
+        return picker_button
+
     def _special_seasons_check_button_toggled_cb(self, button):
         self.settings.setConf(Settings.ADD_SPECIAL_SEASONS, button.get_active())
 
     def _screen_rotation_picker_button_changed_cb(self, button):
         self.settings.setConf(Settings.SCREEN_ROTATION, button.get_active())
 
+    def _episodes_check_picker_button_changed_cb(self, button):
+        self.settings.setConf(Settings.EPISODES_CHECK_POSITION,
+                              button.get_active())
+
 def show_information(parent, message):
     hildon.hildon_banner_show_information(parent,
                                           '',
